## 📖 Atualizacoes diarias 
## **Equipe de desenvolvimento de Atualizacoes diarias**
  - Conceito: para que uma empresa de software se mantenha viva é necessario equipes que trabalham diariamente e recebem um salario por isso , em nosso caso Nossa equipe iniciara os trabalhos as 07:00:00 e o salario é o custos de token de cada agente
  - Anotacoes: modificaremos o script que chama a equipe com um loop de 5 atualizacoes no horario de 07:00:00 
  - Objetivos: 